# Obsidian ELN Import

Obsidian ELN Import is program written in Python to import metadata from analytical data files and stores them in the yaml frontmatter of a markdown file.

The program is designed to work with Obsidian ELN which is an [Electronic Lab Notebook](https://en.wikipedia.org/wiki/Electronic_lab_notebook) (ELN) that is based on the [Obsidian](https://obsidian.md/) markdown editor. 

Obsidian ELN and Obsidian ELN Import were developed to support researchers in the field of materials science and chemistry to collect and organize their research data. The aim is to automate the process of importing metadata from analytical data files as much as possible and to generate automated reports for supported data types. This will allow researchers to focus more on their research while benefiting from the advantages of a well structured, indexable, and electronically searchable ELN.

In future versions it is also planned to provide support to export the data to public repositories to make the data available to other researchers and data scientists. 

## Features

- Import metadata from analytical data files and store them in the yaml frontmatter of a markdown file
- Generate automated reports for supported data types
- Currently supported data types: 
  - SmartSEM TIF files (Zeiss)
  - MPT files (BioLogic)
  - more to come...


 